import { performance} from'perf_hooks'
const {now} = performance

import {
  createWorld,
  registerComponent,
  registerComponents,
  defineComponent,
  defineQuery,
  Changed,
  Not,
  enterQuery,
  exitQuery,
  defineSystem,
  addComponent,
  removeComponent,
  addEntity,
  removeEntity,
  defineSerializer,
  defineDeserializer,
  Types,
} from './src/index.js'

const world = createWorld()

const { f32 } = Types
const Vector2 = { x: f32, y: f32 }
const Position = defineComponent(Vector2)
const Velocity = defineComponent(Vector2)
registerComponents(world, [Position, Velocity])

const query = defineQuery([Changed(Position),Velocity])
const serialize = defineSerializer([Changed(Position)])
const deserialize = defineDeserializer([Position,Velocity])

const n = 100_000
for (let i = 0; i < n; i++) {
  const eid = addEntity(world)
  addComponent(world, Position, eid)
  addComponent(world, Velocity, eid)
  Position.x[eid]++
  Position.y[eid]++
}

let then

console.log(`n = ${n}`)

then = now()
const ents = query(world)
console.log('query', (now()-then).toFixed(2))

then = now()
const packet = serialize(ents)
console.log('serialize', (now()-then).toFixed(2))

then = now()
deserialize(packet)
console.log('deserialize', (now()-then).toFixed(2))
